Enum serde_test::Error
[−]
[src]
pub enum Error {
Custom(String),
InvalidValue(String),
EndOfStream,
InvalidType(Type),
InvalidLength(usize),
UnknownVariant(String),
UnknownField(String),
MissingField(&'static str),
DuplicateField(&'static str),
InvalidName(&'static str),
UnexpectedToken(Token<'static>),
}Variants
Custom(String)InvalidValue(String)EndOfStreamInvalidType(Type)InvalidLength(usize)UnknownVariant(String)UnknownField(String)MissingField(&'static str)DuplicateField(&'static str)InvalidName(&'static str)UnexpectedToken(Token<'static>)Trait Implementations
impl Clone for Error[src]
fn clone(&self) -> Error
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for Error[src]
fn eq(&self, __arg_0: &Error) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, __arg_0: &Error) -> bool
This method tests for !=.
impl Debug for Error[src]
impl Error for Error[src]
fn custom<T: Into<String>>(msg: T) -> Error
Raised when there is a general error when serializing a type.
fn invalid_value(msg: &str) -> Error
Raised when a Serialize was passed an incorrect value.
impl Error for Error[src]
fn custom<T: Into<String>>(msg: T) -> Error
Raised when there is general error when deserializing a type.
fn end_of_stream() -> Error
Raised when a Deserialize type unexpectedly hit the end of the stream.
fn invalid_type(ty: Type) -> Error
Raised when a Deserialize was passed an incorrect type.
fn invalid_value(msg: &str) -> Error
Raised when a Deserialize was passed an incorrect value.
fn invalid_length(len: usize) -> Error
Raised when a fixed sized sequence or map was passed in the wrong amount of arguments. Read more
fn unknown_variant(variant: &str) -> Error
Raised when a Deserialize enum type received an unexpected variant.
fn unknown_field(field: &str) -> Error
Raised when a Deserialize struct type received an unexpected struct field.
fn missing_field(field: &'static str) -> Error
raised when a deserialize struct type did not receive a field.
fn duplicate_field(field: &'static str) -> Error
Raised when a Deserialize struct type received more than one of the same struct field. Read more
impl Display for Error[src]
fn fmt(&self, formatter: &mut Formatter) -> Result<(), Error>
Formats the value using the given formatter.